inferpy package
===============

Subpackages
-----------

.. toctree::

   inferpy.contextmanager
   inferpy.datasets
   inferpy.inference
   inferpy.models
   inferpy.queries
   inferpy.util

Module contents
---------------

.. automodule:: inferpy
   :members:
   :undoc-members:
   :show-inheritance:
